@@ -353,3 +353,29 @@ off_t lseek_net(int filedes, off_t offset, int whence) {
 	retval=offset+1;
 	return(retval);
 }
+
+FILE *fopen_net(const char *path, const char *mode) {
+	FILE *ret = NULL;
+	int fd = -1;
+	mode_t openmode = -1;
+
+	if (strcmp(mode, "r") == 0) {
+		openmode = O_RDONLY;
+	}
+	if (strcmp(mode, "w") == 0) {
+		openmode = O_WRONLY;
+	}
+
+	if (openmode != O_WRONLY && openmode != O_RDONLY) {
+		return(NULL);
+	}
+
+	fd = open_net(path, openmode, 0644);
+	if (fd < 0) {
+		return(NULL);
+	}
+
+	ret = fdopen(fd, mode);
+
+	return(ret);
+}
