@@ -22,6 +22,8 @@
 #define _OPENNET_H
 #include <sys/types.h>
 #include <unistd.h>
+#include <stdio.h>
+
 
 #ifdef  __cplusplus
 extern "C" {
@@ -39,6 +41,9 @@ off_t lseek_net(int filedes, off_t offset, int whence);
 /* A more deterministic POSIX read(). */
 ssize_t read_net(int fd, void *buf, size_t count);
 
+/* ANSI fopen() clone. */
+FILE *fopen_net(const char *path, const char *mode);
+
 #ifdef  __cplusplus
 }
 #endif
